package Const::XS;

use 5.006;
use strict;
use warnings;

our $VERSION = '0.01';

use base qw/Import::Export/;

our %EX = (
        const => [qw/all/]
);

require XSLoader;
XSLoader::load("Const::XS", $VERSION);

__END__

1;


=head1 NAME

Const::XS - The great new Const::XS!

=head1 VERSION

Version 0.01

=cut

=head1 SYNOPSIS

	use Const::XS;

	const my $scalar => 'Hello World';
	const my @array => qw/welcome to paradise/;
	const my %hash => ( one => 1, two => 2, three => 3 );


=head1 AUTHOR

LNATION, C<< <email at lnation.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-const-xs at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Const-XS>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

	perldoc Const::XS

You can also look for information at:

=over 2

=item * RT: CPAN's request tracker (report bugs here)

L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Const-XS>

=item * Search CPAN

L<https://metacpan.org/release/Const-XS>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2025 by LNATION.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut

1; # End of Const::XS
